#!/bin/sh
#
# Telelogic DOORS Installation script (database server)
#

# -----------------------------------------------------------
# IBM Confidential
# 
# DOORS - %full_filespec: instserv.sh~7:shsrc:ERS#1 %  %date_created: Mon Sep 22 15:44:04 2008 %
#
# (c) Copyright IBM Corporation 1993, 2008. All Rights Reserved.
# -----------------------------------------------------------

defdestpath="/users/doors"
defdatapath="/users/doors/data"
programname="instserv.sh"
datapath=""
cdrompath=$1
installpath=""
installdata="n"
username=""
archs=""
instserver="y"
echocmd="echo"
dfcmd="df"
sameversion="n"

load_common() 
{
    commonsh=$cdrompath"/""`echo doors/unix/common/common.sh | eval $fnc`"
    . $commonsh
}

get_fnc()
{
    if [ `basename $0` = $programname ] ; then
	fnc="cat -"
	pnc="cat -"
    else 
	fnc="sed -e 's/$/;1/' | tr \"[:lower:]\" \"[:upper:]\""
	pnc="tr \"[:lower:]\" \"[:upper:]\""
   fi

   thisarch=$cdrompath"/""`echo unix/bin/getarch.sh | eval $fnc`"
   thisarch=`$thisarch`
   thisarch=`echo $thisarch | eval $pnc`

   availarchs=$cdrompath"/""`echo doors/unix | eval $pnc`"
   availarchs=`ls $availarchs`

}

hpecho()
{
    if [ "X$1" = "X-n" ] ; then
        shift
        printf "%s" "$*"
    else
        printf "%s\n" "$*"
    fi
}


get_echocmd()
{
sys_name=`uname -s`
sys_release=`uname -r`
 
    if [ "${sys_name}" = "HP-UX" ] ; then
        echocmd="hpecho" 
    fi
    if [ "${sys_name}" = "SunOS" ] ; then
        case $sys_release in
                5*)
                    echocmd="/usr/ucb/echo" ;;
                *)
        esac
    fi
}

get_cmds()
{
    case $thisarch in
      hpux )
	dfcmd="/usr/bin/bdf"
        ;;
      alpha)
	dfcmd="/bin/df -k"
        ;;
      aix)
        dfcmd="/bin/df -I"
        ;;
      sunos )
	dfcmd="/usr/bin/df"
        ;;
      solaris )
        echocmd="/usr/ucb/echo"
	dfcmd="/bin/df -k"
        ;;
    esac
}

show_archs_2()
{ 

    $echocmd
    for arch in $archs
    do
        $echocmd "Install configured for " $arch "."
    done
    $echocmd
}

get_architecture()
{
    print_banner
    $echocmd -n "Select architectures to install [ "

    for arch in $availarchs
    do
	if [ "${arch}" != "common" -a "${arch}" != "COMMON" ] ; then
	    $echocmd -n $arch " "
	fi
    done
    $echocmd " ]"

    def="n"

    for arch in $availarchs
    do
	# do not present the opportunity to install the common stuff
	# for a server install

	if [ "${arch}" != "common" -a "${arch}" != "COMMON" ] ; then
	    def="n"
	    if [ "${arch}" = "${thisarch}" ] ; then
		def="y"
	    fi
	    $echocmd -n "Install for " ${arch} " [" ${def} "]: "
	    read resp
	    if [ "${resp}" = "" ] ; then
		    resp=$def
	    fi
	    if [ "${resp}" = "y" ] ; then
		archs=${archs}" "${arch}
	    fi
	fi
    done
}

show_archs()
{
    print_banner
    $echocmd "Options configured"
    $echocmd
    $echocmd "Distribution path          : " $cdrompath
    $echocmd "Install path               : " $installpath
    $echocmd "Telelogic DOORS admin user : " $username
    $echocmd 
    $echocmd -n "Demo database    : "
    if [ "${install_data}" = "y" ] ; then
        $echocmd "Install"
	$echocmd "Database path    : " $datapath
    fi

    if [ "${install_data}" != "y" ] ; then
        $echocmd "Don't Install"
    fi
    show_archs_2
}

build_directories()
{
    $echocmd Constructing directory structure
    if [ $sameversion = "n" ] ; then
	move_directory $installpath/bin
	mkdir $installpath/bin 2>> /tmp/doorslog
        move_directory $installpath/etc
        mkdir $installpath/etc 2>> /tmp/doorslog
    else
        if [ ! -d $installpath/bin ] ; then
	    mkdir $installpath/bin 2>> /tmp/doorslog
        fi
	if [ ! -d $installpath/etc ] ; then
	    mkdir $installpath/etc 2>> /tmp/doorslog
	fi
    fi
}

install_common()
{
    $echocmd Installing common software
    com_instpath=$cdrompath"/""`echo doors/unix/common/scommon.tar | eval $fnc`"
    cd $installpath
    tar xf $com_instpath  2>> /tmp/doorslog
}

install_specific()
{
    $echocmd Installing architecture specific software
    cd $installpath
    for arch in $archs
    do
        $echocmd Installing for $arch
	archserv_instpath=$cdrompath"/""`echo doors/unix/$arch/s$arch.tar | eval $fnc`"
	tar xf $archserv_instpath 2>> /tmp/doorslog
    done
}

set_perms()
{
    $echocmd "Setting file permissions"

    find $installpath/bin -name "*" -exec chown $username {} ";"
    find $installpath/etc -name "*" -exec chown $username {} ";"
    chown $username $installpath 2>> /tmp/doorslog 

    if [ "${install_data}" = "y" ] ; then
        $echocmd "Setting database file permissions"
        find $datapath -name "*" -exec chown $username {} ";"
    fi
}



if [ "${DOORSHOME}" ] ; then
    defdestpath=$DOORSHOME
fi
if [ "${DOORSDATA}" ] ; then
    defdatapath=$DOORSDATA
fi


echo "Telelogic DOORS Installation log" > /tmp/doorslog
get_echocmd
get_fnc
load_common
print_banner
get_install_path "DOORS server"
check_version
get_cmds
get_doors_user
get_architecture
show_archs

build_directories

if [ "${archs}" ] ; then 
    install_common
    install_specific
fi


DOORSHOME=$installpath
export DOORSHOME

set_perms
set_version
$echocmd
$echocmd "Installation complete."
$echocmd
$echocmd "Telelogic DOORS user should add the following lines to their profiles (sh or ksh)"
$echocmd "        DOORSHOME="$installpath
if [ "${datapath}" ] ; then 
    $echocmd "        SERVERDATA="$datapath
else
    $echocmd "        SERVERDATA=(path to the DOORS data directory)"
fi

$echocmd "        PATH=""$""DOORSHOME/bin:""$""PATH"
$echocmd "        export DOORSHOME SERVERDATA PATH"

$echocmd ""
$echocmd "See Telelogic DOORS installation manual for instructions for starting the DOORS"
$echocmd "database server."
